import React, { useState, useEffect } from 'react';
import { Form, Button, DatePicker, Table, Pagination, Radio, Typography } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request'

/**
  @param {*} props
  @returns
 */
const { RangePicker } = DatePicker;
const { Text } = Typography;

function record(props) {
    const { getFieldDecorator } = props.form

    // 获取初始化数据
    const [data, setData] = useState({})

    useEffect(() => {
        getList({ pageNum: 1, pageSize: 10 });
    }, [])

    // 查询列表
    const getList = (params) => {
        request({ ...apis.activity.saleCountList, params: { ...params }, }).then((data) => {
            setData(data)
            console.log("data:", data)
        })
    }

    //重置搜索
    function handleReset() {
        props.form.resetFields();
    }

    // 分享详情
    function shareCount(personId) {
        router.push({
            pathname: '/record/share/shareCountList',
            query: {
                id: personId,
            },
        });
    }

    // 点击人数详情
    function clickCount(personId) {
        router.push({
            pathname: '/record/share/clickCountList',
            query: {
                id: personId,
            },
        });
    }

    // 提交事件
    const handleSubmit = (e, props) => {
        e.preventDefault();
        props.form.validateFields((err, values) => {
            if (!err) {
                let { shareTime, receiveTime, ...submitValue } = values
                if (null != shareTime && shareTime.length > 0) {
                    const [startCreateDate, endCreateDate] = shareTime
                    submitValue.startCreateDate = moment(startCreateDate).format('YYYY-MM-DD');
                    submitValue.endCreateDate = moment(endCreateDate).format('YYYY-MM-DD');
                } else {
                    submitValue.startCreateDate = null
                    submitValue.endCreateDate = null
                }
                console.log(submitValue)
                getList({ pageNum: 1, pageSize: 10, ...submitValue })
            }
        });
    }

    const changePageNum = (pageNumber) => {
        props.form.validateFields((err, values) => {
            if (!err) {
                let { shareTime, receiveTime, ...submitValue } = values
                if (null != shareTime && shareTime.length > 0) {
                    const [startCreateDate, endCreateDate] = shareTime
                    submitValue.startCreateDate = moment(startCreateDate).format('YYYY-MM-DD');
                    submitValue.endCreateDate = moment(endCreateDate).format('YYYY-MM-DD');
                } else {
                    submitValue.startCreateDate = null
                    submitValue.endCreateDate = null
                }
                getList({ pageNum: pageNumber, pageSize: 10, ...submitValue })
            }
        });
    }
    function getDataOf(days) {
        // this.setState({ endDate: new Date(), startDate: moment().subtract(days, 'day').toDate() })
    }
    const columns = [

        {
            title: '项目',
            dataIndex: 'buildingName',
            key: 'buildingName',
            align: 'center',
        },
        {
            title: '置业顾问名称1',
            dataIndex: 'consultantName',
            key: 'consultantName',
            align: 'center',
        },
        {
            title: '置业顾问电话',
            dataIndex: 'consultantPhone',
            key: 'consultantPhone',
            align: 'center',
        },
        {
            title: '客户总计',
            dataIndex: 'customerAggregate',
            key: 'customerAggregate',
            align: 'center',
            sorter: (a, b) => a.customerAggregate - b.customerAggregate,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => shareCount(record.personId)} >{record.customerAggregate}</span></>,
        },
        {
            title: '新增客户',
            dataIndex: 'newCustomers',
            key: 'newCustomers',
            align: 'center',
            sorter: (a, b) => a.newCustomers - b.newCustomers,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => shareCount(record.personId)} >{record.newCustomers}</span></>,
        },
        {
            title: '分享次数',
            dataIndex: 'shareCount',
            key: 'shareCount',
            align: 'center',
            sorter: (a, b) => a.shareCount - b.shareCount,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => shareCount(record.personId)} >{record.shareCount}</span></>,
        },
        {
            title: '分享访问人数',
            dataIndex: 'shareVisitPersonNum',
            key: 'shareVisitPersonNum',
            align: 'center',
            sorter: (a, b) => a.shareVisitPersonNum - b.shareVisitPersonNum,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => shareCount(record.personId)} >{record.shareVisitPersonNum}</span></>,
        },
        {
            title: '分享访问次数',
            dataIndex: 'shareVisitNum',
            key: 'shareVisitNum',
            align: 'center',
            sorter: (a, b) => a.shareVisitNum - b.shareVisitNum,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => shareCount(record.personId)} >{record.shareVisitNum}</span></>,
        },

        {
            title: '分享拓客',
            dataIndex: 'sharePossess',
            key: 'sharePossess',
            align: 'center',
            sorter: (a, b) => a.sharePossess - b.sharePossess,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => clickCount(record.personId)} >{record.sharePossess}</span></>,
        },
        {
            title: '主页访问人数',
            dataIndex: 'visitPerson',
            key: 'visitPerson',
            align: 'center',
            sorter: (a, b) => a.visitPerson - b.visitPerson,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => clickCount(record.personId)} >{record.visitPerson}</span></>,
        },
        {
            title: '主页访问次数',
            dataIndex: 'clickNum',
            key: 'clickNum',
            align: 'center',
            sorter: (a, b) => a.clickNum - b.clickNum,
            render: (_, record) => <><span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => clickCount(record.personId)} >{record.clickNum}</span></>,
        },
    ];



    return (

        <>
            <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
                <div style={{ display: 'flex', alignItems: 'center' }}>
                    <Radio.Group buttonStyle="solid" defaultValue="a" style={{ marginRight: '16px', }}>
                        <Radio.Button value="a" onClick={getDataOf(7)}>最近7天</Radio.Button>
                        <Radio.Button value="b" onClick={getDataOf(30)}>最近1月</Radio.Button>
                    </Radio.Group>
                    <Form.Item>
                        {getFieldDecorator('shareTime')(
                            <RangePicker placeholder={['开始日期', '结束日期']} />
                        )}
                    </Form.Item>
                    <Form.Item>
                        {getFieldDecorator('buildingId')(
                            <BuildSelect />,
                        )}
                    </Form.Item>
                    <Form.Item style={{ position: 'absolute', right: '38px' }}>
                        <Button type="primary" onClick={handleReset}>查询</Button>
                        <Button style={{ marginLeft: 8 }} onClick={handleReset}>重置</Button>
                    </Form.Item>
                </div>
            </Form>
            <Table rowKey="KPIRecords"
                style={{ marginTop: '30px' }}
                dataSource={data.records}
                columns={columns}
                pagination={false}
            />
            < div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </>
    )
}
const WrappedHeader = Form.create({ name: 'record' })(record);

export default WrappedHeader
